==> google-cloud-sdk-434.0.0-darwin-x86_64.tar.gz: google-cloud-sdk/lib/surface/netapp/__init__.py <==
# -*- coding: utf-8 -*- #
# Copyright 2022 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""The super-group for the Cloud NetApp Files CLI."""

from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

from googlecloudsdk.calliope import base

DETAILED_HELP = {
    'DESCRIPTION':
        """\
      The gcloud netapp command group lets you create, configure and manipulate
      Cloud NetApp Files resources such as Volumes, Storage Pools, etc.

      With Cloud NetApp Files, you can take advantage of Google Cloud Platform's
      scale, performance and value to manage and run on-prem NetApp Files
      solutions on Google infrastructure, so you don't have to modernize your
      file workloads, and allow for legacy feature support.

      More information on Cloud NetApp Files can be found here:
      https://cloud.google.com/netapp/docs/reference/rest
      """,
}


@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
class Netapp(base.Group):
  """Create and manipulate Cloud NetApp Files resources."""
  detailed_help = DETAILED_HELP
  category = base.STORAGE_CATEGORY


@base.Hidden
@base.ReleaseTracks(base.ReleaseTrack.BETA)
class NetappBeta(base.Group):
  """Create and manipulate Cloud NetApp Files resources."""
  detailed_help = DETAILED_HELP
  category = base.STORAGE_CATEGORY

==> google-cloud-sdk-442.0.0-darwin-x86_64.tar.gz: google-cloud-sdk/lib/surface/netapp/__init__.py <==
# -*- coding: utf-8 -*- #
# Copyright 2022 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""The super-group for the Cloud NetApp Files CLI."""

from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

from googlecloudsdk.calliope import base

DETAILED_HELP = {
    'DESCRIPTION':
        """\
      The gcloud netapp command group lets you create, configure and manipulate
      Cloud NetApp Volumes resources such as Volumes, Storage Pools, Active Directories,
      KMS Configs, Volume Snapshots, and Volume Replications etc.

      With Cloud NetApp Volumes, you can take advantage of Google Cloud Platform's
      scale, performance and value to manage and run on-prem NetApp Files
      solutions on Google infrastructure, so you don't have to modernize your
      file workloads, and allow for legacy feature support.

      More information on Cloud NetApp Files can be found here:
      https://cloud.google.com/netapp/docs/reference/rest
      """,
}


@base.ReleaseTracks(base.ReleaseTrack.ALPHA, base.ReleaseTrack.BETA)
class Netapp(base.Group):
  """Create and manipulate Cloud NetApp Files resources."""
  detailed_help = DETAILED_HELP
  category = base.STORAGE_CATEGORY
